NoOpCommand top-level constant
String
const NoOpCommand
Sentinel value for a command that does nothing (e.g., no fields to update).
Implementation
const String NoOpCommand = 'NOOP';
Sentinel value for a command that does nothing (e.g., no fields to update).
const String NoOpCommand = 'NOOP';