SQL class

Explicit SQL-null marker for dynamic commands.

Primarily used with UpdateCommand and InsertCommand to distinguish between "omit this field" (plain null) and "set this field to NULL" (SQL.NULL).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

NULL → const SQL